const fs = require('fs');
const path = require('path');
const express = require('express');
const expressThymeleaf = require('express-thymeleaf');
const thymeleaf = require('thymeleaf');
const router = express.Router();

const {TemplateEngine, StandardDialect} = thymeleaf

const publicDir = require('path').join(__dirname, '/output');

const app = express();
app.use(express.static(publicDir));
 
let templateEngine = new TemplateEngine({
  dialects: [
    new StandardDialect('th')
  ]
});
app.engine('html', expressThymeleaf(templateEngine));
app.set('view engine', 'html');

function getThymeleaf(fileName, params, handle) {
  const filePath = path.join(__dirname, 'output', fileName)
  console.log(`-----------------${filePath}`)
  return templateEngine.processFile(filePath, params)
  .then(result => {
    return result
  });
}

router.get('/index', function(req, res, next) {
  console.log(`-----------------${req.url}`)
  getThymeleaf('index.html', {
    username: 'ghlin',
  })
  .then(result => {
    res.send(result)
  });
});

app.use('/', router)

app.listen(3000, () => {
  console.info(`__start_api||port=3000||env=${process.env.NODE_ENV}`)
});

// 参考:
// https://www.jianshu.com/p/e3ff54ae30ce
// https://tomoya92.github.io/2017/03/09/thymeleaf-layout/
// https://pagination.js.org/
// https://ultraq.github.io/thymeleaf-layout-dialect/