/*!
 * Start Bootstrap - SB Admin 2 v4.0.3 (https://startbootstrap.com/template-overviews/sb-admin-2)
 * Copyright 2013-2020 Start Bootstrap
 * Licensed under MIT (https://github.com/BlackrockDigital/gaokao_qhd/blob/master/LICENSE)
 */

"use strict";

(function () {
  function jobRateChart(val) {
    var chart = echarts.init(document.getElementById('jobRateStat'));
    chart.setOption({
      title: {
        text: '就业率统计',
        x: 'center'
      },
      tooltip: {
        trigger: 'item',
        formatter: "{a} <br/>{b}: {c} ({d}%)"
      },
      series: [{
        name: '就业率',
        type: 'pie',
        radius: ['50%', '70%'],
        avoidLabelOverlap: false,
        label: {
          normal: {
            show: true,
            position: 'center'
          },
          emphasis: {
            show: true,
            textStyle: {
              fontSize: '30',
              fontWeight: 'bold'
            }
          }
        },
        labelLine: {
          normal: {
            show: false
          }
        },
        data: [{
          value: val,
          name: val + "%"
        }, {
          value: 100 - val,
          name: ''
        }]
      }]
    });
  }

  function upgradeRateChart(val) {
    var chart = echarts.init(document.getElementById('upgradeRateStat'));
    chart.setOption({
      title: {
        text: '升学率统计',
        x: 'center'
      },
      tooltip: {
        trigger: 'item',
        formatter: "{a} <br/>{b}: {c} ({d}%)"
      },
      series: [{
        name: '升学率',
        type: 'pie',
        radius: ['50%', '70%'],
        avoidLabelOverlap: false,
        label: {
          normal: {
            show: true,
            position: 'center'
          },
          emphasis: {
            show: true,
            textStyle: {
              fontSize: '30',
              fontWeight: 'bold'
            }
          }
        },
        labelLine: {
          normal: {
            show: false
          }
        },
        data: [{
          value: val,
          name: val + "%"
        }, {
          value: 100 - val,
          name: ''
        }]
      }]
    });
  }

  function abroadRateChart(val) {
    var chart = echarts.init(document.getElementById('abroadRateStat'));
    chart.setOption({
      title: {
        text: '出国率统计',
        x: 'center'
      },
      tooltip: {
        trigger: 'item',
        formatter: "{a} <br/>{b}: {c} ({d}%)"
      },
      series: [{
        name: '出国率',
        type: 'pie',
        radius: ['50%', '70%'],
        avoidLabelOverlap: false,
        label: {
          normal: {
            show: true,
            position: 'center'
          },
          emphasis: {
            show: true,
            textStyle: {
              fontSize: '30',
              fontWeight: 'bold'
            }
          }
        },
        labelLine: {
          normal: {
            show: false
          }
        },
        data: [{
          value: val,
          name: val + "%"
        }, {
          value: 100 - val,
          name: ''
        }]
      }]
    });
  }

  function provinceChart(data) {
    var chart = echarts.init(document.getElementById('provinceChart'));
    chart.setOption({
      tooltip: {
        trigger: 'item',
        formatter: "{a} <br/>{b}: {c} ({d}%)"
      },
      series: [{
        name: '就业省份',
        type: 'pie',
        radius: '80%',
        center: ['50%', '60%'],
        data: data,
        itemStyle: {
          emphasis: {
            shadowBlur: 10,
            shadowOffsetX: 0,
            shadowColor: 'rgba(0, 0, 0, 0.5)'
          }
        }
      }]
    });
  }

  function jobAttrChart(data) {
    var chart = echarts.init(document.getElementById('jobAttrChart'));
    chart.setOption({
      tooltip: {
        trigger: 'item',
        formatter: "{a} <br/>{b}: {c} ({d}%)"
      },
      series: [{
        name: '单位性质',
        type: 'pie',
        radius: '80%',
        center: ['50%', '60%'],
        data: data,
        itemStyle: {
          emphasis: {
            shadowBlur: 10,
            shadowOffsetX: 0,
            shadowColor: 'rgba(0, 0, 0, 0.5)'
          }
        }
      }]
    });
  }

  function companyChart(data) {
    var chart = echarts.init(document.getElementById('companyChart'));
    chart.setOption({
      tooltip: {
        trigger: 'item',
        formatter: "{a} <br/>{b}: {c} ({d}%)"
      },
      series: [{
        name: '就业单位',
        type: 'pie',
        radius: '80%',
        center: ['50%', '60%'],
        data: data,
        itemStyle: {
          emphasis: {
            shadowBlur: 10,
            shadowOffsetX: 0,
            shadowColor: 'rgba(0, 0, 0, 0.5)'
          }
        }
      }]
    });
  }

  $(document).ready(function () {
    if (globalSchoolDetailData.jobs && globalSchoolDetailData.jobs.length > 0) {
      var job = globalSchoolDetailData.jobs[0];
      jobRateChart(job.jobRate);
      upgradeRateChart(job.postgraduate);
      abroadRateChart(job.abroad);
    }

    if (globalSchoolDetailData.jobProvinces && globalSchoolDetailData.jobProvinces.length > 0) {
      var jps = globalSchoolDetailData.jobProvinces.map(function (e) {
        return {
          value: e.num,
          name: e.province
        };
      });
      provinceChart(jps);
    }

    if (globalSchoolDetailData.jobAttrs && globalSchoolDetailData.jobAttrs.length > 0) {
      var _jps = globalSchoolDetailData.jobAttrs.map(function (e) {
        return {
          value: e.rate,
          name: e.orgType
        };
      });

      jobAttrChart(_jps);
    }

    if (globalSchoolDetailData.jobCompanies && globalSchoolDetailData.jobCompanies.length > 0) {
      var _jps2 = globalSchoolDetailData.jobCompanies.map(function (e) {
        return {
          value: e.rate,
          name: e.companyName
        };
      });

      companyChart(_jps2);
    }
  });
})();