/*!
 * Start Bootstrap - SB Admin 2 v4.0.3 (https://startbootstrap.com/template-overviews/sb-admin-2)
 * Copyright 2013-2020 Start Bootstrap
 * Licensed under MIT (https://github.com/BlackrockDigital/gaokao_qhd/blob/master/LICENSE)
 */

"use strict";

(function () {
  var pageObj = {
    size: 100,
    page: 1
  };
  var batchDict = ["本科一批", "本科二批", "专科"];
  var yearDict = [2018, 2017, 2016];
  var typeDict = ["理科", "文科"];
  var scoreDict = ["最低分", "最高分", "平均分"]; // const scoreEnDict = ["min", "max", "average"]

  function schoolRow2Column(rows) {
    // 此结果是一个二维数组
    // 例如: [["本科一批", "文科", "最低分", "600", "590", "580", "595"]]
    var results = [];
    batchDict.forEach(function (batch) {
      typeDict.forEach(function (type) {
        // 找出批次, 科目对应的分数
        var batchTypeDatas = _.filter(rows, {
          localBatchName: batch,
          localTypeName: type
        });

        if (batchTypeDatas.length === 0) {
          // 如果没有找到对应批次, 则返回
          return;
        }

        var yearMap = {}; // 每一年的最低,最高,平均

        yearDict.forEach(function (year) {
          var yearData = _.find(batchTypeDatas, {
            year: year
          });

          yearMap[year] = {
            '最低分': yearData ? yearData.min : -1,
            // min 对应 scoreEnName[0]
            '最高分': yearData ? yearData.max : -1,
            // max 对应 scoreEnName[1]
            '平均分': yearData ? yearData.average : -1 // average 对应 scoreEnName[2]

          };
        });
        scoreDict.forEach(function (scoreName) {
          var resultItem = [batch, type, scoreName];
          yearDict.forEach(function (year, index) {
            resultItem.push(yearMap[year][scoreName]);
          });
          results.push(resultItem);
        });
      });
    });
    return results;
  }

  function renderSchoolFunc(result) {
    var rows = result.content;

    if (!result.page || !result.page.totalElements) {
      return "<tr><td colspan=\"20\">无数据</td></tr>";
      ;
    }

    var datas = schoolRow2Column(rows);
    var items = [];
    datas.forEach(function (row, index) {
      items.push("<tr>");

      if (index % 3 === 0) {
        items.push("<td rowspan=3 style='line-height:125px;'>" + row[0] + "</td>");
        items.push("<td rowspan=3 style='line-height:125px;'>" + row[1] + "</td>");
      }

      items.push("<td>" + row[2] + "</td>");
      items.push("<td>" + row[3] + "</td>");
      items.push("<td>" + row[4] + "</td>");
      items.push("<td>" + row[5] + "</td>");
      items.push("</tr>");
    });
    return items.join("");
  }

  function getSchoolParams() {
    var name = $("#schoolName").text().trim();
    var p = {
      name: name
    };
    return Object.assign({}, pageObj, p);
  }

  var schoolUrl = "api/lineSchools/search/pageBy";

  function loadSchoolData() {
    return $.getJSON(schoolUrl, getSchoolParams() || params, function (data) {
      return data;
    }).then(function (data) {
      if (data) {
        $("#table-body-school").html(renderSchoolFunc(data));
      }
    });
  } // ----------------------------


  function renderMajorFunc(result) {
    var rows = result.content;

    if (!result.page || !result.page.totalElements) {
      return "<tr><td colspan=\"20\">无数据</td></tr>";
      ;
    }

    var datas = _.filter(rows, function (r) {
      return r.year !== 2014 && r.year !== 2015;
    }).sort(function (a, b) {
      return a.year >= b.year ? -1 : 1;
    });

    var items = [];
    $.each(datas, function (key, val) {
      items.push("<tr>");
      items.push("<td width='200px'>" + val.spname + "</td>");
      items.push("<td>" + val.year + "</td>");
      items.push("<td>" + val.max + "</td>");
      items.push("<td>" + val.min + "</td>");
      items.push("<td>" + val.average + "</td>");
      items.push("<td>" + val.localBatchName + "</td>");
      items.push("</tr>");
    });
    return items.join("");
  }

  function getMajorParams() {
    var name = $("#schoolName").text().trim();
    var year = $("#majorYearSelect").val();
    var p = {
      name: name
    };

    if (year) {
      p.year = year;
    }

    return Object.assign({}, pageObj, p);
  }

  var majorUrl = "api/lineMajors/search/pageBy";

  function loadMajorData() {
    return $.getJSON(majorUrl, getMajorParams() || params, function (data) {
      return data;
    }).then(function (data) {
      if (data) {
        $("#table-body-major").html(renderMajorFunc(data));
        $("#pageSelection-major").bootstrapPaginator({
          currentPage: 1,
          totalPages: data.page.totalPages,
          ajaxOption: {
            url: majorUrl,
            size: pageObj.size,
            appendElement: "table-body-major",
            renderFunc: renderMajorFunc,
            otherParams: getMajorParams
          }
        });
      }
    });
  }

  $(document).ready(function () {
    loadSchoolData();
    loadMajorData();
    $("#schoolYearSelect").on("change", function (e) {
      loadSchoolData();
    });
    $("#majorYearSelect").on("change", function (e) {
      loadMajorData();
    });
    $("nav.bd-links").on("click", "a", function (e) {
      e.preventDefault();
      var ah = $(this).attr('href');
      $('html, body').animate({
        scrollTop: $("" + ah).offset().top
      }, 500);
    });
    var $sideNav = $("#sideNav");
    var offset = $sideNav.offset();
    $(window).scroll(function () {
      var scrollTop = $(window).scrollTop();

      if (offset.top < scrollTop) {
        $sideNav.attr('style', 'position:fixed; top: 10px;');
      } else {
        $sideNav.attr('style', 'position:relative');
      }
    });
  });
})();